@@ -105,11 +105,11 @@ class mysqlUtil:
 
     def get_files_bypid(self, pid):
         if pid:
-            pid = str(pid).upper()
+            pid = str(pid).lower()
             sql = 'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         else:
-            pid = "p023101"
+            pid = "p023101".lower()
             'select id,url,fdesc,fsize,duration,ftype,uptime,pid from sftp_files where pid="{}" order by uptime desc limit 100'.format(
                 pid)
         df = pd.read_sql(sql, self.engine)
